==> haskell-text-format-0.3.2.1-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-format
version:              0.3.2.1
visibility:           public
id:                   text-format-0.3.2.1-DaFtEqgoIhEe5Fxi2xurz
key:                  text-format-0.3.2.1-DaFtEqgoIhEe5Fxi2xurz
license:              BSD-3-Clause
maintainer:           Hackage Trustees
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/hackage-trustees/text-format
synopsis:             Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.

category:             Text
abi:                  86fa32604e9920bfcfcc800d86291646
exposed:              True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal

hidden-modules:       Data.Text.Format.Functions Data.Text.Format.Int
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-format-0.3.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-format-0.3.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-format-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-format
hs-libraries:         HStext-format-0.3.2.1-DaFtEqgoIhEe5Fxi2xurz
depends:
    array-0.5.4.0 base-4.17.2.1
    double-conversion-2.0.5.0-GwnxRuV6XDO86cRW1OqKJ4 ghc-prim-0.9.1
    integer-gmp-1.1 old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    text-2.0.2 time-1.12.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html:         /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-format-0.3.2.1-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-format
version:              0.3.2.1
visibility:           public
id:                   text-format-0.3.2.1-LQ2lWuu5DVwEJqDzZVEPK7
key:                  text-format-0.3.2.1-LQ2lWuu5DVwEJqDzZVEPK7
license:              BSD-3-Clause
maintainer:           Hackage Trustees
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/hackage-trustees/text-format
synopsis:             Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.

category:             Text
abi:                  71c610c38e6d2f4ae5c439b2094f9615
exposed:              True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal

hidden-modules:       Data.Text.Format.Functions Data.Text.Format.Int
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-format-0.3.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-format-0.3.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-format-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-format
hs-libraries:         HStext-format-0.3.2.1-LQ2lWuu5DVwEJqDzZVEPK7
depends:
    array-0.5.4.0 base-4.17.2.1
    double-conversion-2.0.5.0-1Al8H7vq9Fc6tpUtdAGC0 ghc-prim-0.9.1
    integer-gmp-1.1 old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    text-2.0.2 time-1.12.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html:         /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
